import { GraphQLSchema, GraphQLFieldResolver, DocumentNode, OperationDefinitionNode } from 'graphql';
import { GraphQLExtension } from 'graphql-extensions';
import { DataSource } from 'apollo-datasource';
import { PersistedQueryOptions } from '.';
import { CacheControlExtensionOptions } from 'apollo-cache-control';
import { GraphQLRequest, GraphQLResponse, GraphQLRequestContext, InvalidGraphQLRequestError, ValidationRule } from './requestPipelineAPI';
import { ApolloServerPlugin } from 'apollo-server-plugin-base';
export { GraphQLRequest, GraphQLResponse, GraphQLRequestContext, InvalidGraphQLRequestError, };
export interface GraphQLRequestPipelineConfig<TContext> {
    schema: GraphQLSchema;
    rootValue?: ((document: DocumentNode) => any) | any;
    validationRules?: ValidationRule[];
    fieldResolver?: GraphQLFieldResolver<any, TContext>;
    dataSources?: () => DataSources<TContext>;
    extensions?: Array<() => GraphQLExtension>;
    tracing?: boolean;
    persistedQueries?: PersistedQueryOptions;
    cacheControl?: CacheControlExtensionOptions;
    formatError?: Function;
    formatResponse?: Function;
    plugins?: ApolloServerPlugin[];
}
export declare type DataSources<TContext> = {
    [name: string]: DataSource<TContext>;
};
export interface GraphQLRequestPipeline<TContext> {
    willExecuteOperation?(operation: OperationDefinitionNode): void;
}
export declare class GraphQLRequestPipeline<TContext> {
    private config;
    constructor(config: GraphQLRequestPipelineConfig<TContext>);
    processRequest(requestContext: GraphQLRequestContext<TContext>): Promise<GraphQLResponse>;
    private initializeExtensionStack;
    private initializeDataSources;
}
//# sourceMappingURL=requestPipeline.d.ts.map