import { Request, Headers } from 'apollo-server-env';
import { GraphQLSchema, ValidationContext, ASTVisitor, GraphQLError, OperationDefinitionNode } from 'graphql';
import { KeyValueCache } from 'apollo-server-caching';
export interface GraphQLServiceContext {
    schema: GraphQLSchema;
    engine: {
        serviceID?: string;
    };
    persistedQueries?: {
        cache: KeyValueCache;
    };
}
export interface GraphQLRequest {
    query?: string;
    operationName?: string;
    variables?: {
        [name: string]: any;
    };
    extensions?: Record<string, any>;
    http: Pick<Request, 'url' | 'method' | 'headers'>;
}
export interface GraphQLResponse {
    data?: object;
    errors?: GraphQLError[];
    extensions?: Record<string, any>;
    http?: {
        headers: Headers;
    };
}
export interface GraphQLRequestContext<TContext> {
    request: GraphQLRequest;
    response?: GraphQLResponse;
    context: TContext;
    cache: KeyValueCache;
    operation?: OperationDefinitionNode;
    debug?: boolean;
}
export declare type ValidationRule = (context: ValidationContext) => ASTVisitor;
export declare class InvalidGraphQLRequestError extends Error {
}
//# sourceMappingURL=requestPipelineAPI.d.ts.map