import { Request } from 'apollo-server-env';
import { GraphQLSchema, GraphQLFieldResolver, ValidationContext, ASTVisitor, DocumentNode, GraphQLError, ExecutionResult, OperationDefinitionNode } from 'graphql';
import { GraphQLExtension, GraphQLExtensionStack } from 'graphql-extensions';
import { PersistedQueryOptions } from './';
import { CacheControlExtensionOptions } from 'apollo-cache-control';
export interface GraphQLRequest {
    query?: string;
    operationName?: string;
    variables?: {
        [name: string]: any;
    };
    extensions?: Record<string, any>;
    httpRequest?: Pick<Request, 'url' | 'method' | 'headers'>;
}
export interface GraphQLRequestOptions<TContext = any> {
    schema: GraphQLSchema;
    rootValue?: ((parsedQuery: DocumentNode) => any) | any;
    context: TContext;
    validationRules?: ValidationRule[];
    fieldResolver?: GraphQLFieldResolver<any, TContext>;
    debug?: boolean;
    extensions?: Array<() => GraphQLExtension>;
    queryExtensions?: Record<string, any>;
    tracing?: boolean;
    persistedQueries?: PersistedQueryOptions;
    cacheControl?: CacheControlExtensionOptions;
    formatResponse?: Function;
}
export declare type ValidationRule = (context: ValidationContext) => ASTVisitor;
export declare class InvalidGraphQLRequestError extends Error {
}
export interface GraphQLResponse {
    data?: object;
    errors?: GraphQLError[];
    extensions?: Record<string, any>;
}
export interface GraphQLRequestProcessor {
    willExecuteOperation?(operation: OperationDefinitionNode): void;
}
export declare class GraphQLRequestProcessor {
    options: GraphQLRequestOptions;
    context: any;
    extensionStack: GraphQLExtensionStack;
    constructor(options: GraphQLRequestOptions);
    initializeExtensions(): void;
    processRequest(request: GraphQLRequest): Promise<GraphQLResponse>;
    private willSendResponse;
    parse(query: string): DocumentNode;
    validate(document: DocumentNode): ReadonlyArray<GraphQLError>;
    execute(document: DocumentNode, operationName: GraphQLRequest['operationName'], variables: GraphQLRequest['variables']): Promise<ExecutionResult>;
}
//# sourceMappingURL=requestProcessing.d.ts.map